@@ -7,7 +7,6 @@ from __future__ import unicode_literals
 
 import os
 import random
-import scipy.misc
 import numpy as np
 from antgo.utils import get_rng
 from antgo.dataflow.core import *
@@ -19,7 +18,6 @@ import tarfile
 import zipfile
 from antgo import config
 import subprocess
-from antgo.utils.dht import *
 from antgo.utils.serialize import *
 import copy
 import cv2
@@ -41,7 +39,6 @@ def imwrite(file, img):
 
 
 def imresize(image, size):
-  # return scipy.misc.imresize(image, size)
   return cv2.resize(image, (size[1],size[0]))
 
 
@@ -50,7 +47,7 @@ class Dataset(BaseNode):
 
   def __init__(self, train_or_test="train", dir=None, ext_params=None, name=None):
     super(Dataset, self).__init__(name)
-    assert(train_or_test in ["train", "val", "test", "sample"])
+    assert(train_or_test in ["train", "val", "test", "sample", 'unlabeled'])
 
     # for random episodes
     self.nb_samples = 0
@@ -353,9 +350,37 @@ class Dataset(BaseNode):
   def __iter__(self):
     return self.iterator_value()
 
+  def __len__(self):
+    return self.size
+
+  def __getitem__(self, index):
+    return self.at(index)
+
   def at(self, id):
-    return None
+    raise NotImplementedError
+
+  def get_ann_info(self, idx=None):
+    raise NotImplementedError
+    
+  def get_cat_ids(self, idx):
+    raise NotImplementedError
   
+  def sample(self, id):
+    image, annotation = self.at(id)
+    if not isinstance(annotation, dict):
+      annotation = {'label': annotation}
+
+    if image is not None:
+      annotation['image'] = image
+    return annotation
+
+  def evaluate(self, preds, **kwargs):
+    raise NotImplementedError
+
+  @property
+  def size(self):
+    raise NotImplementedError
+
   @property
   def rng(self):
     if self._is_data_rng:
